# 　　其中有分为：
# 　　算法封装：模板方法、策略、命令模式
# 　　对象去耦：中介、观察者模式
# 　　抽象集合：迭代器模式
# 　　行为扩展：访问者、责任链模式
# 　　对象状态：状态模式
# 　　解释器模式



# 　　行为扩展：责任链模式

from .watcher import Watcher
from .steg import Strategy
from .state import State
from .order import Order
from .mediator import Mediator
from .fwz import Visitor
from .explan import Explain

