# 适配器模式、
# 
# 装饰器模式、
# 代理模式、
# 外观模式、
# 桥接模式、
# 组合模式和
# 享元模式。
from .shareyuan import ShareYuan
from .decorator import Decorator
from .connect import Connect
from .combo import Combo
from .appearance import Appearance
from .agent import Agent
from .adapter import Adapter